@@ -1569,9 +1569,11 @@ class Class(hyperdb.Class):
 
         "search_matches" is {nodeid: marker} or None
 
-        The filter must match all properties specificed - but if the
-        property value to match is a list, any one of the values in the
-        list may match for that property to match.
+        The filter must match all properties specificed. If the property
+        value to match is a list:
+        
+        1. String properties must match all elements in the list, and
+        2. Other properties must match any of the elements in the list.
         """
         if __debug__:
             start_t = time.time()
