@@ -11,6 +11,12 @@ from MimeWriter import MimeWriter
 from roundup.rfc2822 import encode_header
 from roundup import __version__
 
+try:
+    from email.Utils import formatdate
+except ImportError:
+    def formatdate(timeval):
+        return time.strftime("%a, %d %b %Y %H:%M:%S +0000", timeval)
+
 class MessageSendError(RuntimeError):
     pass
 
@@ -54,8 +60,7 @@ class Mailer:
         writer.addheader('Subject', encode_header(subject, charset))
         writer.addheader('To', ', '.join(to))
         writer.addheader('From', author)
-        writer.addheader('Date', time.strftime("%a, %d %b %Y %H:%M:%S +0000",
-                                               time.gmtime()))
+        writer.addheader('Date', formatdate(time.gmtime()))
 
         # Add a unique Roundup header to help filtering
         writer.addheader('X-Roundup-Name', encode_header(tracker_name,
@@ -115,7 +120,7 @@ class Mailer:
         part = writer.nextpart()
         part.addheader('Content-Transfer-Encoding', 'quoted-printable')
         body = part.startbody('text/plain; charset=utf-8')
-        body.write('\n'.join(error))
+        body.write(quopri.encodestring ('\n'.join(error)))
 
         # attach the original message to the returned message
         part = writer.nextpart()
