@@ -260,7 +260,7 @@ class DBTest(MyTestCase):
             b = self.db.issue.get(nid, "deadline")
             if commit: self.db.commit()
             self.assertNotEqual(a, b)
-            self.assertNotEqual(b, date.Date('1970-1-1 00:00:00'))
+            self.assertNotEqual(b, date.Date('1970-1-1.00:00:00'))
 
     def testDateUnset(self):
         for commit in (0,1):
